@file:Suppress("DEPRECATION")

package com.taiwanmobile.pt.adp.mediation

import android.app.Activity
import android.content.Context
import android.os.Bundle
import com.google.android.gms.ads.AdRequest
import com.google.android.gms.ads.AdSize
import com.google.android.gms.ads.mediation.MediationAdRequest
import com.google.android.gms.ads.mediation.customevent.CustomEventBanner
import com.google.android.gms.ads.mediation.customevent.CustomEventBannerListener
import com.taiwanmobile.pt.adp.view.*

// 需將本class的完整類別名稱 com.taiwanmobile.pt.adp.mediation.TAmediaBanner註冊於中介服務群組
class TAmediaBanner : CustomEventBanner {

    private var adView: TWMAdView? = null

    override fun requestBannerAd(
        context: Context,
        customEventBannerListener: CustomEventBannerListener,
        serverParameter: String?,
        adSize: AdSize,
        mediationAdRequest: MediationAdRequest,
        bundle: Bundle?
    ) {
        adView = TWMAdView(context as Activity, convertAdSize(adSize), serverParameter)
        adView?.adListener = object : TWMAdViewListener {
            override fun onReceiveAd(ad: TWMAd) {
                adView?.let {
                    customEventBannerListener.onAdLoaded(it)
                }
            }

            override fun onFailedToReceiveAd(ad: TWMAd, errorCode: TWMAdRequest.ErrorCode) {
                customEventBannerListener.onAdFailedToLoad(
                    convertErrorCode(errorCode)
                )
            }

            override fun onPresentScreen(ad: TWMAd) {
                customEventBannerListener.onAdOpened()
            }

            override fun onDismissScreen(ad: TWMAd) {
                customEventBannerListener.onAdClosed()
            }

            override fun onLeaveApplication(ad: TWMAd) {
                customEventBannerListener.onAdClicked()
                customEventBannerListener.onAdLeftApplication()
            }
        }
        adView?.loadAd(TWMAdRequest())
    }

    override fun onDestroy() {
        adView?.destroy()
    }

    override fun onPause() {}
    override fun onResume() {}

    //將AdMob的AdSize轉換為TWMAdSize
    private fun convertAdSize(adSize: AdSize): TWMAdSize {
        return when {
            isAdSizeEqual(adSize, TWMAdSize.BANNER) -> {
                TWMAdSize.BANNER
            }
            isAdSizeEqual(adSize, TWMAdSize.BANNER_1200X627) -> {
                TWMAdSize.BANNER_1200X627
            }
            isAdSizeEqual(adSize, TWMAdSize.BANNER_300X250) -> {
                TWMAdSize.BANNER_300X250
            }
            isAdSizeEqual(adSize, TWMAdSize.SMART_BANNER) -> {
                TWMAdSize.SMART_BANNER
            }
            else -> {
                TWMAdSize.BANNER
            }
        }
    }

    private fun isAdSizeEqual(adSize: AdSize, twmAdSize: TWMAdSize): Boolean {
        return (adSize.width == twmAdSize.width
                && adSize.height == twmAdSize.height)
    }

    private fun convertErrorCode(errorCode: TWMAdRequest.ErrorCode): Int {
        return when (errorCode) {
            TWMAdRequest.ErrorCode.INTERNAL_ERROR -> {
                AdRequest.ERROR_CODE_INTERNAL_ERROR
            }
            TWMAdRequest.ErrorCode.INVALID_REQUEST -> {
                AdRequest.ERROR_CODE_INVALID_REQUEST
            }
            TWMAdRequest.ErrorCode.NETWORK_ERROR -> {
                AdRequest.ERROR_CODE_NETWORK_ERROR
            }
            TWMAdRequest.ErrorCode.NO_FILL -> {
                AdRequest.ERROR_CODE_NO_FILL
            }
            else -> AdRequest.ERROR_CODE_NETWORK_ERROR
        }
    }
}