@file:Suppress("DEPRECATION")

package com.taiwanmobile.pt.adp.mediation

import android.app.Activity
import android.content.Context
import android.os.Bundle
import com.google.android.gms.ads.AdRequest
import com.google.android.gms.ads.mediation.MediationAdRequest
import com.google.android.gms.ads.mediation.customevent.CustomEventInterstitial
import com.google.android.gms.ads.mediation.customevent.CustomEventInterstitialListener
import com.taiwanmobile.pt.adp.view.TWMAd
import com.taiwanmobile.pt.adp.view.TWMAdRequest
import com.taiwanmobile.pt.adp.view.TWMAdViewListener
import com.taiwanmobile.pt.adp.view.TWMInterstitialAd

// 需將本class的完整類別名稱 com.taiwanmobile.pt.adp.mediation.TAmediaInterstitial註冊於中介服務群組
class TAmediaInterstitial : CustomEventInterstitial {

    private var interstitialAd: TWMInterstitialAd? = null

    override fun requestInterstitialAd(
        context: Context,
        customEventInterstitialListener: CustomEventInterstitialListener,
        serverParameter: String?,
        mediationAdRequest: MediationAdRequest,
        bundle: Bundle?
    ) {
        interstitialAd = TWMInterstitialAd(context as Activity, serverParameter as String)
        interstitialAd?.setAdListener(object : TWMAdViewListener {

            override fun onReceiveAd(ad: TWMAd) {
                customEventInterstitialListener.onAdLoaded()
            }

            override fun onFailedToReceiveAd(ad: TWMAd, errorCode: TWMAdRequest.ErrorCode) {
                customEventInterstitialListener.onAdFailedToLoad(
                    convertErrorCode(errorCode)
                )
            }

            override fun onPresentScreen(ad: TWMAd) {
                customEventInterstitialListener.onAdOpened()
            }

            override fun onDismissScreen(ad: TWMAd) {
                customEventInterstitialListener.onAdClosed()
            }

            override fun onLeaveApplication(ad: TWMAd) {
                customEventInterstitialListener.onAdClicked()
                customEventInterstitialListener.onAdLeftApplication()
            }
        })
        interstitialAd?.loadAd(TWMAdRequest())
    }

    override fun showInterstitial() {
        interstitialAd?.show()
    }

    override fun onDestroy() {
        interstitialAd?.destroy()
    }

    override fun onPause() {}
    override fun onResume() {}

    private fun convertErrorCode(errorCode: TWMAdRequest.ErrorCode): Int {
        return when (errorCode) {
            TWMAdRequest.ErrorCode.INTERNAL_ERROR -> {
                AdRequest.ERROR_CODE_INTERNAL_ERROR
            }
            TWMAdRequest.ErrorCode.INVALID_REQUEST -> {
                AdRequest.ERROR_CODE_INVALID_REQUEST
            }
            TWMAdRequest.ErrorCode.NETWORK_ERROR -> {
                AdRequest.ERROR_CODE_NETWORK_ERROR
            }
            TWMAdRequest.ErrorCode.NO_FILL -> {
                AdRequest.ERROR_CODE_NO_FILL
            }
            else -> AdRequest.ERROR_CODE_NETWORK_ERROR
        }
    }
}