@file:Suppress("DEPRECATION")

package com.taiwanmobile.pt.adp.mediation

import android.content.Context
import android.os.Bundle
import com.google.android.gms.ads.mediation.NativeMediationAdRequest
import com.google.android.gms.ads.mediation.customevent.CustomEventNative
import com.google.android.gms.ads.mediation.customevent.CustomEventNativeListener
import com.taiwanmobile.pt.adp.nativead.TWMNativeAdOptions
import com.taiwanmobile.pt.adp.view.TWMAdRequest
import com.taiwanmobile.pt.adp.view.TWMNativeAd

// 需將本class的完整類別名稱 com.taiwanmobile.pt.adp.mediation.TAmediaNative註冊於中介服務群組
class TAmediaNative : CustomEventNative {

    private var twmNativeAd: TWMNativeAd? = null
    // optional. Set true when the feature below is needed.
    // http://wiki.tamedia.com.tw/androidDoc/library/com.taiwanmobile.pt.adp.nativead/-t-w-m-native-ad-options/index.html
    private val videoStartUnmuted = false
    private val disableImageLoading = false
    private val videoCustomControlRequest = false
    private val mediaPreferImage = false

    override fun onDestroy() {
        twmNativeAd?.destroy()
    }

    override fun onPause() {}

    override fun onResume() {}

    override fun requestNativeAd(
        context: Context,
        customEventNativeListener: CustomEventNativeListener,
        serverParameter: String?,
        nativeMediationAdRequest: NativeMediationAdRequest,
        extra: Bundle?
    ) {
        serverParameter?.let { twmAdUnitId ->
            twmNativeAd = TWMNativeAd(context, twmAdUnitId).also { nativeAd ->
                nativeAd.setAdListener(
                    TAmediaNativeEventForwarder(
                        customEventNativeListener,
                        nativeMediationAdRequest.nativeAdRequestOptions
                    )
                )
            }.apply {
                val request = TWMAdRequest().apply {
                    val nativeAdOptions = mutableListOf<TWMNativeAdOptions>()
                    if (videoStartUnmuted) {
                        nativeAdOptions.add(TWMNativeAdOptions.VIDEO_START_UNMUTED)
                    }
                    if (disableImageLoading) {
                        nativeAdOptions.add(TWMNativeAdOptions.DISABLE_IMAGE_LOADING)
                    }
                    if (videoCustomControlRequest) {
                        nativeAdOptions.add(TWMNativeAdOptions.VIDEO_CUSTOM_CONTROLS_REQUESTED)
                    }
                    if (mediaPreferImage) {
                        nativeAdOptions.add(TWMNativeAdOptions.MEDIA_PREFER_IMAGE)
                    }
                    if (nativeAdOptions.size > 0) {
                        setNativeAdOptions(nativeAdOptions.toTypedArray())
                    }
                }
                loadAd(request)
            }
        }
    }

}