@file:Suppress("DEPRECATION")

package com.taiwanmobile.pt.adp.mediation.adapter

import android.app.Activity
import android.content.Context
import android.os.Bundle
import android.view.View
import com.google.android.gms.ads.AdError
import com.google.android.gms.ads.AdRequest
import com.google.android.gms.ads.AdSize
import com.google.android.gms.ads.mediation.*
import com.google.android.gms.ads.mediation.MediationConfiguration.CUSTOM_EVENT_SERVER_PARAMETER_FIELD
import com.taiwanmobile.pt.adp.TWMMobileAds
import com.taiwanmobile.pt.adp.mediation.TAmediaNativeAdMapper
import com.taiwanmobile.pt.adp.view.*

class TAmediaCustomEvent : Adapter(),
    MediationBannerAdapter,
    MediationInterstitialAdapter,
    MediationNativeAdapter {

    private var adView: TWMAdView? = null
    private var interstitialAd: TWMInterstitialAd? = null
    private var nativeAd: TWMNativeAd? = null

    // TAmedia error domain.
    private val ERROR_DOMAIN = "com.taiwanmobile.pt.tamedia"

    // NO_FILL
    private val ERROR_CODE_NO_FILL = AdRequest.ERROR_CODE_NO_FILL
    private val ERROR_MESSAGE_NO_FILL = "AD NO_FILL"

    // INVALID_SERVER_PARAMETER
    private val ERROR_CODE_INVALID_SERVER_PARAMETER = AdRequest.ERROR_CODE_INVALID_AD_STRING
    private val ERROR_MESSAGE_INVALID_SERVER_PARAMETER = "Missing or invalid SDK Key"


    /**
     * 回傳TAmedia SDK Version
     */
    override fun getSDKVersionInfo(): VersionInfo {
        val versionArray = TWMMobileAds.getSDKVersion().split(".")
        return if (versionArray.size == 3) {
            VersionInfo(
                versionArray[0].toInt(),
                versionArray[1].toInt(),
                versionArray[2].toInt()
            )
        } else {
            VersionInfo(1, 0, 0)
        }
    }

    /**
     * 回傳Adapter版本, 1.0.0
     */
    override fun getVersionInfo(): VersionInfo {
        return VersionInfo(1, 0, 0)
    }

    override fun initialize(
        context: Context,
        initializeCallback: InitializationCompleteCallback,
        configurations: MutableList<MediationConfiguration>
    ) {
        initializeCallback.onInitializationSucceeded()
    }

    override fun onDestroy() {
        adView?.destroy()
        interstitialAd?.destroy()
        nativeAd?.destroy()
    }

    override fun onPause() {}

    override fun onResume() {}

    /**
     * Banner Implementation
     */
    override fun getBannerView(): View {
        return adView!!
    }

    /**
     * Banner Implementation
     */
    override fun requestBannerAd(
        context: Context,
        bannerListener: MediationBannerListener,
        serverParameters: Bundle,
        adSize: AdSize,
        adRequest: MediationAdRequest,
        mediationExtras: Bundle?
    ) {
        val adUnitID = serverParameters.get(CUSTOM_EVENT_SERVER_PARAMETER_FIELD) as String?
        if (adUnitID.isNullOrBlank()) {
            bannerListener.onAdFailedToLoad(
                this,
                AdError(
                    ERROR_CODE_INVALID_SERVER_PARAMETER,
                    ERROR_MESSAGE_INVALID_SERVER_PARAMETER,
                    ERROR_DOMAIN
                )
            )
            return
        }
        val size = when (adSize) {
            AdSize.MEDIUM_RECTANGLE -> {
                TWMAdSize.BANNER_300X250
            }
            else -> {
                TWMAdSize.BANNER
            }
        }
        adView = TWMAdView(context as Activity, size, adUnitID)
        adView?.adListener = object : TWMAdViewListener {
            override fun onReceiveAd(ad: TWMAd) {
                adView.let {
                    bannerListener.onAdLoaded(this@TAmediaCustomEvent)
                }
            }

            override fun onFailedToReceiveAd(ad: TWMAd, errorCode: TWMAdRequest.ErrorCode) {
                bannerListener.onAdFailedToLoad(
                    this@TAmediaCustomEvent,
                    AdError(
                        ERROR_CODE_NO_FILL,
                        ERROR_MESSAGE_NO_FILL,
                        ERROR_DOMAIN
                    )
                )
            }

            override fun onPresentScreen(ad: TWMAd) {}
            override fun onDismissScreen(ad: TWMAd) {}
            override fun onLeaveApplication(ad: TWMAd) {
                bannerListener.onAdClicked(this@TAmediaCustomEvent)
                bannerListener.onAdLeftApplication(this@TAmediaCustomEvent)
            }
        }
        adView?.loadAd(TWMAdRequest())
    }

    /**
     * Interstitial Implementation
     */
    override fun requestInterstitialAd(
        context: Context,
        interstitialListener: MediationInterstitialListener,
        serverParameters: Bundle,
        adRequest: MediationAdRequest,
        mediationExtras: Bundle?
    ) {
        val adUnitID = serverParameters.get(CUSTOM_EVENT_SERVER_PARAMETER_FIELD) as String?
        if (adUnitID.isNullOrBlank()) {
            interstitialListener.onAdFailedToLoad(
                this,
                AdError(
                    ERROR_CODE_INVALID_SERVER_PARAMETER,
                    ERROR_MESSAGE_INVALID_SERVER_PARAMETER,
                    ERROR_DOMAIN
                )
            )
            return
        }
        interstitialAd = TWMInterstitialAd(context as Activity, adUnitID)
        interstitialAd?.setAdListener(object : TWMAdViewListener {

            override fun onReceiveAd(ad: TWMAd) {
                interstitialListener.onAdLoaded(this@TAmediaCustomEvent)
            }

            override fun onFailedToReceiveAd(ad: TWMAd, errorCode: TWMAdRequest.ErrorCode) {
                interstitialListener.onAdFailedToLoad(
                    this@TAmediaCustomEvent,
                    AdError(
                        ERROR_CODE_NO_FILL,
                        ERROR_MESSAGE_NO_FILL,
                        ERROR_DOMAIN
                    )
                )
            }

            override fun onPresentScreen(ad: TWMAd) {}

            override fun onDismissScreen(ad: TWMAd) {}

            override fun onLeaveApplication(ad: TWMAd) {
                interstitialListener.onAdClicked(this@TAmediaCustomEvent)
                interstitialListener.onAdLeftApplication(this@TAmediaCustomEvent)
            }
        })
        interstitialAd?.loadAd(TWMAdRequest())
    }

    /**
     * Interstitial Implementation
     */
    override fun showInterstitial() {
        interstitialAd?.show()
    }

    /**
     * Native Implementation
     */
    override fun requestNativeAd(
        context: Context,
        nativeListener: MediationNativeListener,
        serverParameters: Bundle,
        adRequest: NativeMediationAdRequest,
        mediationExtras: Bundle?
    ) {
        val adUnitID = serverParameters.get(CUSTOM_EVENT_SERVER_PARAMETER_FIELD) as String?
        if (adUnitID.isNullOrBlank()) {
            nativeListener.onAdFailedToLoad(
                this,
                AdError(
                    ERROR_CODE_INVALID_SERVER_PARAMETER,
                    ERROR_MESSAGE_INVALID_SERVER_PARAMETER,
                    ERROR_DOMAIN
                )
            )
            return
        }
        nativeAd = TWMNativeAd(context, adUnitID).also { nativeAd ->
            nativeAd.setAdListener(NativeEventForwarder(this, nativeListener))
        }.apply {
            loadAd(TWMAdRequest())
        }
    }

    /**
     * Native Implementation
     */
    inner class NativeEventForwarder(
        private val adapter: MediationNativeAdapter,
        private val listener: MediationNativeListener
    ) : TWMAdViewListener {

        override fun onDismissScreen(ad: TWMAd) {}

        override fun onFailedToReceiveAd(ad: TWMAd, errorCode: TWMAdRequest.ErrorCode) {
            listener.onAdFailedToLoad(
                adapter,
                AdError(
                    ERROR_CODE_NO_FILL,
                    ERROR_MESSAGE_NO_FILL,
                    ERROR_DOMAIN
                )
            )
        }

        override fun onLeaveApplication(ad: TWMAd) {
            listener.onAdClicked(adapter)
            listener.onAdLeftApplication(adapter)
        }

        override fun onPresentScreen(ad: TWMAd) {
            listener.onAdImpression(adapter)
        }

        override fun onReceiveAd(ad: TWMAd) {
            val mapper = TAmediaNativeAdMapper(ad as TWMNativeAd)
            listener.onAdLoaded(adapter, mapper)
        }


    }

}