package com.taiwanmobile.pt.gam.mediation

import android.app.Activity
import android.util.Log
import android.view.View
import com.google.android.gms.ads.AdSize
import com.google.android.gms.ads.mediation.MediationAdLoadCallback
import com.google.android.gms.ads.mediation.MediationBannerAd
import com.google.android.gms.ads.mediation.MediationBannerAdCallback
import com.google.android.gms.ads.mediation.MediationBannerAdConfiguration
import com.taiwanmobile.pt.adp.view.*

class TAmediaGAMBannerLoader(
    private val configuration: MediationBannerAdConfiguration,
    private val callback: MediationAdLoadCallback<MediationBannerAd, MediationBannerAdCallback>
) : MediationBannerAd {

    private lateinit var adView: TWMAdView
    private lateinit var mediationBannerAdCallback: MediationBannerAdCallback

    // Interface - MediationBannerAd
    override fun getView(): View {
        return adView
    }

    fun loadAd() {
        val context = configuration.context
        val adUnitId = configuration.serverParameters.getString("parameter")
        val adSize = when (configuration.adSize) {
            AdSize.BANNER -> { TWMAdSize.BANNER }
            AdSize.MEDIUM_RECTANGLE -> { TWMAdSize.BANNER_300X250 }
            else -> { TWMAdSize.BANNER }
        }
        adView = TWMAdView(context as Activity, adSize, adUnitId)
        adView.adListener = object : TWMAdViewListener {
            override fun onReceiveAd(ad: TWMAd) {
                adView.let {
                    mediationBannerAdCallback = callback.onSuccess(this@TAmediaGAMBannerLoader)
                    mediationBannerAdCallback.reportAdImpression()
                }
            }
            override fun onFailedToReceiveAd(ad: TWMAd, errorCode: TWMAdRequest.ErrorCode) {
                callback.onFailure(TAmediaGAMCustomEvent.AdError_NO_FILL)
            }
            override fun onPresentScreen(ad: TWMAd) {
                Log.d("tag", "onPresentScreen")
            }
            override fun onDismissScreen(ad: TWMAd) {
                Log.d("tag", "onDismissScreen")
            }
            override fun onLeaveApplication(ad: TWMAd) {
                mediationBannerAdCallback.onAdLeftApplication()
                mediationBannerAdCallback.reportAdClicked()
            }
        }
        adView.loadAd(TWMAdRequest())
    }
    fun destroy() {
        adView.destroy()
    }
}