@file:Suppress("DEPRECATION")

package com.taiwanmobile.pt.gam.mediation

import android.content.Context
import com.google.android.gms.ads.AdError
import com.google.android.gms.ads.AdRequest
import com.google.android.gms.ads.VersionInfo
import com.google.android.gms.ads.mediation.*
import com.taiwanmobile.pt.adp.TWMMobileAds

// 需將本class的完整類別名稱 com.taiwanmobile.pt.gam.mediation.TAmediaGAMCustomEvent
// 撰寫於 收益群組->收益夥伴
class TAmediaGAMCustomEvent : Adapter(), MediationAdapter {

    private var bannerLoader: TAmediaGAMBannerLoader? = null
    private var interstitialLoader: TAmediaGAMInterstitialLoader? = null
    private var nativeLoader: TAmediaGAMNativeLoader? = null

    enum class MediaType {
        VIDEO,
        BIG_IMAGE,
        SMALL_IMAGE
    }

    override fun loadBannerAd(
        configuration: MediationBannerAdConfiguration,
        callback: MediationAdLoadCallback<MediationBannerAd, MediationBannerAdCallback>
    ) {
        bannerLoader = TAmediaGAMBannerLoader(configuration, callback)
        bannerLoader?.loadAd()
    }

    override fun loadInterstitialAd(
        configuration: MediationInterstitialAdConfiguration,
        callback: MediationAdLoadCallback<MediationInterstitialAd, MediationInterstitialAdCallback>
    ) {
        interstitialLoader = TAmediaGAMInterstitialLoader(configuration, callback)
        interstitialLoader?.loadAd()
    }

    override fun loadNativeAd(
        configuration: MediationNativeAdConfiguration,
        callback: MediationAdLoadCallback<UnifiedNativeAdMapper, MediationNativeAdCallback>
    ) {
        nativeLoader = TAmediaGAMNativeLoader(configuration, callback)
        nativeLoader?.loadAd()
    }

    override fun getSDKVersionInfo(): VersionInfo {
        val versionArray = TWMMobileAds.getSDKVersion().split(".")
        return when (versionArray.size == 3) {
            true -> {
                VersionInfo(
                    versionArray[0].toInt(),
                    versionArray[1].toInt(),
                    versionArray[2].toInt()
                )
            } else -> {
                VersionInfo(1, 0, 0)
            }
        }
    }

    override fun getVersionInfo(): VersionInfo {
        return VersionInfo(1, 1, 0)
    }

    override fun initialize(
        context: Context,
        initializationCompleteCallback: InitializationCompleteCallback,
        configuration: MutableList<MediationConfiguration>
    ) {
        initializationCompleteCallback.onInitializationSucceeded()
    }

    override fun onDestroy() {
        bannerLoader?.destroy()
        nativeLoader?.destroy()
    }

    override fun onPause() {}

    override fun onResume() {}

    companion object {
        val AdError_NO_FILL = AdError(
            AdRequest.ERROR_CODE_NO_FILL,
            "No fill",
            TWMMobileAds::class.java.toString()
        )
    }
}