package com.taiwanmobile.pt.gam.mediation

import android.app.Activity
import android.content.Context
import com.google.android.gms.ads.mediation.MediationAdLoadCallback
import com.google.android.gms.ads.mediation.MediationInterstitialAd
import com.google.android.gms.ads.mediation.MediationInterstitialAdCallback
import com.google.android.gms.ads.mediation.MediationInterstitialAdConfiguration
import com.taiwanmobile.pt.adp.view.TWMAd
import com.taiwanmobile.pt.adp.view.TWMAdRequest
import com.taiwanmobile.pt.adp.view.TWMAdViewListener
import com.taiwanmobile.pt.adp.view.TWMInterstitialAd
import com.taiwanmobile.pt.gam.mediation.TAmediaGAMCustomEvent.Companion.AdError_NO_FILL

class TAmediaGAMInterstitialLoader(
    private val configuration: MediationInterstitialAdConfiguration,
    private val callback: MediationAdLoadCallback<MediationInterstitialAd, MediationInterstitialAdCallback>
) : MediationInterstitialAd {

    private lateinit var interstitialAd: TWMInterstitialAd
    private lateinit var mediationInterstitialAdCallback: MediationInterstitialAdCallback

    fun loadAd() {
        val context = configuration.context
        val adUnitId = configuration.serverParameters.getString("parameter")
        if (adUnitId.isNullOrBlank()) {
            callback.onFailure(AdError_NO_FILL)
            return
        }
        interstitialAd = TWMInterstitialAd(context as Activity, adUnitId)
        interstitialAd.setAdListener(object : TWMAdViewListener {
            override fun onReceiveAd(ad: TWMAd) {
                mediationInterstitialAdCallback = callback.onSuccess(this@TAmediaGAMInterstitialLoader)
            }

            override fun onFailedToReceiveAd(ad: TWMAd, errorCode: TWMAdRequest.ErrorCode) {
                callback.onFailure(AdError_NO_FILL)
            }

            override fun onLeaveApplication(ad: TWMAd) {
                mediationInterstitialAdCallback.reportAdClicked()
                mediationInterstitialAdCallback.onAdLeftApplication()
            }

            override fun onPresentScreen(ad: TWMAd) {}
            override fun onDismissScreen(ad: TWMAd) {}
        })
        interstitialAd.loadAd(TWMAdRequest())
    }

    override fun showAd(context: Context) {
        interstitialAd.show()
        mediationInterstitialAdCallback.reportAdImpression()
    }
}