package com.taiwanmobile.pt.gam.mediation

import android.view.View
import android.view.ViewGroup
import android.view.ViewGroup.LayoutParams.MATCH_PARENT
import android.widget.FrameLayout
import com.google.android.gms.ads.mediation.UnifiedNativeAdMapper
import com.google.android.gms.ads.nativead.NativeAdAssetNames
import com.taiwanmobile.pt.adp.nativead.TWMMediaContent
import com.taiwanmobile.pt.adp.nativead.TWMMediaView
import com.taiwanmobile.pt.adp.view.TWMNativeAd
import com.taiwanmobile.pt.adp.view.TWMNativeAdView

class TAmediaGAMNativeAdMapper(
    private val nativeAd: TWMNativeAd,
    private val mediaType: TAmediaGAMCustomEvent.MediaType
    ) : UnifiedNativeAdMapper() {

    init {
        overrideClickHandling = true
        overrideImpressionRecording = true

        // Mapping TWMNativeAd to AdMob Native AD resource
        // headline
        nativeAd.nativeAdContent.longSubject?.let { headline = it }
        // body
        nativeAd.nativeAdContent.body?.let { body = it }
        // call to action
        nativeAd.nativeAdContent.callToAction?.let { callToAction = it }
        // icon
        nativeAd.nativeAdContent.iconSquare?.let { image ->
            image.getDrawable()?.let { drawable ->
                image.getUri()?.let { uri ->
                    icon = TAmediaGAMNativeMappedImage(drawable, uri)
                }
            }
        }
        // mediaView
        nativeAd.nativeAdContent.mediaContent?.let {
            setHasVideoContent(true)
        }
    }

    override fun trackViews(
        containerView: View,
        clickableAssetViews: MutableMap<String, View>,
        nonClickableAssetViews: MutableMap<String, View>
    ) {
        // TWMNativeAdView population
        val twmNativeAdView = TWMNativeAdView(containerView.context).apply {
            // headline
            clickableAssetViews[NativeAdAssetNames.ASSET_HEADLINE]?.let { headlineView ->
                setLongSubjectView(headlineView)
            }
            // body
            clickableAssetViews[NativeAdAssetNames.ASSET_BODY]?.let { bodyView ->
                setBodyView(bodyView)
            }
            // call to action
            clickableAssetViews[NativeAdAssetNames.ASSET_CALL_TO_ACTION]?.let { ctaView ->
                setCallToActionView(ctaView)
            }
            // icon
            clickableAssetViews[NativeAdAssetNames.ASSET_ICON]?.let { iconView ->
                setSquareIconView(iconView)
            }
            // mediaView
            if (hasVideoContent()) {
                clickableAssetViews[NativeAdAssetNames.ASSET_MEDIA_VIDEO]?.let { mediaView ->
                    nativeAd.nativeAdContent.mediaContent?.let { mediaContent ->
                        when (mediaType) {
                            TAmediaGAMCustomEvent.MediaType.VIDEO -> {
                                // TAmedia SDK default behavior, VIDEO (if available) then IMAGE
                            }
                            TAmediaGAMCustomEvent.MediaType.BIG_IMAGE -> {
                                mediaContent.setMainImageSize(TWMMediaContent.ImageSize.BIG)
                            }
                            TAmediaGAMCustomEvent.MediaType.SMALL_IMAGE -> {
                                mediaContent.setMainImageSize(TWMMediaContent.ImageSize.SMALL)
                            }
                        }
                        val taMediaView = TWMMediaView(mediaView.context).apply {
                            setMediaContent(mediaContent)
                            layoutParams = mediaView.layoutParams
                        }
                        // append TWMMediaView on AdMob MediaView
                        (mediaView as FrameLayout?)?.addView(taMediaView)
                        // specify TWMMediaView in TWMNativeAdView
                        setMediaView(taMediaView)
                        // (optional) cta text size
                        taMediaView.setCTATextSize(12.0f)
                        // (optional) video count down text size
                        taMediaView.setVideoCountdownTextSize(14.0f)
                        // (optional) volume image size
                        taMediaView.setVolumeImageSize(20)
                    }
                }
            } else {
                clickableAssetViews[NativeAdAssetNames.ASSET_MEDIA_VIDEO]?.let { mediaView ->
                    mediaView.visibility = View.GONE
                }
            }
            // final step of population, specify TWMNativeAd object to TWMNativeView
            setNativeAd(nativeAd)
        }
        // append TWMNativeAdView on AdMob container view
        twmNativeAdView.layoutParams = ViewGroup.LayoutParams(MATCH_PARENT, MATCH_PARENT)
        (containerView as ViewGroup).addView(twmNativeAdView)
        super.trackViews(containerView, clickableAssetViews, nonClickableAssetViews)

    }
}