package com.taiwanmobile.pt.gam.mediation

import com.google.android.gms.ads.mediation.*
import com.google.gson.Gson
import com.taiwanmobile.pt.adp.nativead.TWMNativeAdOptions
import com.taiwanmobile.pt.adp.view.TWMAd
import com.taiwanmobile.pt.adp.view.TWMAdRequest
import com.taiwanmobile.pt.adp.view.TWMAdViewListener
import com.taiwanmobile.pt.adp.view.TWMNativeAd

class TAmediaGAMNativeLoader(
    private val configuration: MediationNativeAdConfiguration,
    private val loadCallback: MediationAdLoadCallback<UnifiedNativeAdMapper, MediationNativeAdCallback>
    ) : TWMAdViewListener {

    private var nativeAd: TWMNativeAd? = null
    private var mediationCallback: MediationNativeAdCallback? = null
    private var videoStartUnmuted: Boolean = false
    private var videoCustomControlRequest: Boolean = false
    private lateinit var mediaType: TAmediaGAMCustomEvent.MediaType
    private lateinit var adUnitId: String

    fun loadAd() {
        try {
            val context = configuration.context
            val parameters = configuration.serverParameters
                .getString(MediationConfiguration.CUSTOM_EVENT_SERVER_PARAMETER_FIELD)
            val json = Gson().fromJson(parameters, TAmediaGAMNativeAdParameters::class.java)
            mediaType = when (json.parameters.mediaType) {
                TAmediaGAMCustomEvent.MediaType.SMALL_IMAGE.name -> {
                    TAmediaGAMCustomEvent.MediaType.SMALL_IMAGE
                }
                TAmediaGAMCustomEvent.MediaType.BIG_IMAGE.name -> {
                    TAmediaGAMCustomEvent.MediaType.BIG_IMAGE
                }
                else -> { TAmediaGAMCustomEvent.MediaType.VIDEO }
            }
            videoStartUnmuted = json.parameters.videoStartUnmuted ?: false
            videoCustomControlRequest = json.parameters.videoCustomControlRequest ?: false
            adUnitId = json.parameters.adUnitId ?: ""
            when (adUnitId.isBlank()) {
                true -> {
                    loadCallback.onFailure(TAmediaGAMCustomEvent.AdError_NO_FILL)
                }
                else -> {
                    nativeAd = TWMNativeAd(context, adUnitId).also { nativeAd ->
                        nativeAd.setAdListener(this)
                    }.apply {
                        val request = TWMAdRequest().apply {
                            val nativeAdOptions = mutableListOf<TWMNativeAdOptions>()
                            if (videoStartUnmuted) {
                                nativeAdOptions.add(TWMNativeAdOptions.VIDEO_START_UNMUTED)
                            }
                            if (videoCustomControlRequest) {
                                nativeAdOptions.add(TWMNativeAdOptions.VIDEO_CUSTOM_CONTROLS_REQUESTED)
                            }
                            if (mediaType == TAmediaGAMCustomEvent.MediaType.BIG_IMAGE ||
                                mediaType == TAmediaGAMCustomEvent.MediaType.SMALL_IMAGE) {
                                nativeAdOptions.add(TWMNativeAdOptions.MEDIA_PREFER_IMAGE)
                            }
                            if (nativeAdOptions.size > 0) {
                                setNativeAdOptions(nativeAdOptions.toTypedArray())
                            }
                        }
                        loadAd(request)
                    }
                }
            }
        } catch (e: Exception) {
            e.printStackTrace()
            loadCallback.onFailure(TAmediaGAMCustomEvent.AdError_NO_FILL)
        }
    }

    fun destroy() {
        nativeAd?.destroy()
    }

    override fun onFailedToReceiveAd(ad: TWMAd, errorCode: TWMAdRequest.ErrorCode) {
        loadCallback.onFailure(TAmediaGAMCustomEvent.AdError_NO_FILL)
    }
    override fun onLeaveApplication(ad: TWMAd) {
        mediationCallback?.reportAdClicked()
        mediationCallback?.onAdLeftApplication()
    }
    override fun onPresentScreen(ad: TWMAd) {
        mediationCallback?.reportAdImpression()
    }
    override fun onReceiveAd(ad: TWMAd) {
        when (ad is TWMNativeAd) {
            true -> {
                val mapper = TAmediaGAMNativeAdMapper(ad, mediaType)
                mediationCallback = loadCallback.onSuccess(mapper)
            }
            false -> {
                loadCallback.onFailure(TAmediaGAMCustomEvent.AdError_NO_FILL)
            }
        }
    }
    override fun onDismissScreen(ad: TWMAd) {}

}