package com.taiwanmobile.pt.guide

import android.content.Intent
import android.os.Bundle
import androidx.activity.ComponentActivity
import androidx.activity.compose.setContent
import androidx.compose.foundation.Image
import androidx.compose.foundation.background
import androidx.compose.foundation.layout.*
import androidx.compose.foundation.shape.RoundedCornerShape
import androidx.compose.material3.*
import androidx.compose.runtime.Composable
import androidx.compose.ui.Alignment
import androidx.compose.ui.Modifier
import androidx.compose.ui.graphics.Color
import androidx.compose.ui.res.colorResource
import androidx.compose.ui.res.painterResource
import androidx.compose.ui.res.stringResource
import androidx.compose.ui.text.TextStyle
import androidx.compose.ui.text.style.TextAlign
import androidx.compose.ui.tooling.preview.Preview
import androidx.compose.ui.unit.dp
import androidx.compose.ui.unit.sp
import com.taiwanmobile.pt.guide.admob.MainActivity
import com.taiwanmobile.pt.guide.gam.GAMMainActivity

class SelectorActivity : ComponentActivity() {

    @OptIn(ExperimentalMaterial3Api::class)
    override fun onCreate(savedInstanceState: Bundle?) {
        super.onCreate(savedInstanceState)
        setContent {
            Scaffold(
                topBar = {
                    TopAppBar(
                        title = {
                            Text(
                                text = stringResource(id = R.string.app_name),
                                color = Color.White
                            )
                        },
                        colors = TopAppBarDefaults.topAppBarColors(containerColor = Color.Black)
                    )
                }
            ) {
                ActivityLayout()
            }
        }
    }

    @Preview
    @Composable
    fun ActivityLayout() {
        Box(Modifier
            .fillMaxWidth()
            .padding(start = 5.dp, end = 5.dp, top = 70.dp)) {
            Text(
                text = stringResource(id = R.string.hello_world),
                color = Color.Gray,
                modifier = Modifier.align(alignment = Alignment.Center),
                fontSize = 16.sp
            )
        }
        Box(Modifier
            .fillMaxSize()
            .padding(end = 5.dp)) {
            Text(
                text = BuildConfig.VERSION_NAME + "(${BuildConfig.VERSION_CODE})",
                color = Color.Gray,
                modifier = Modifier.align(alignment = Alignment.BottomEnd),
                fontSize = 16.sp
            )
        }
        Column(
            modifier = Modifier
                .fillMaxWidth()
                .fillMaxHeight(),
            verticalArrangement = Arrangement.Center,
            horizontalAlignment = Alignment.CenterHorizontally
        ) {
            Row(
                modifier = Modifier.fillMaxWidth(),
                horizontalArrangement = Arrangement.SpaceEvenly
            ) {
                Button(
                    onClick = {
                        val i = Intent().apply {
                            setClass(this@SelectorActivity, MainActivity::class.java)
                        }
                        startActivity(i)
                    },
                    modifier = Modifier
                        .width(170.dp)
                        .height(60.dp)
                        .background(Color.Transparent),
                    colors = ButtonDefaults.buttonColors(
                        containerColor = colorResource(id = R.color.orange),
                        contentColor = Color.White
                    ),
                    shape = RoundedCornerShape(12.dp)
                )
                {
                    Image(
                        painter = painterResource(R.drawable.ic_admob_logo),
                        contentDescription = "AdMob",
                        modifier = Modifier
                            .padding(end = 10.dp)
                            .size(30.dp)
                    )
                    Text(
                        text = stringResource(id = R.string.admob_name),
                        style = TextStyle(fontSize = 12.sp)
                    )
                }
                Button(
                    onClick = {
                        val i = Intent().apply {
                            setClass(this@SelectorActivity, GAMMainActivity::class.java)
                        }
                        startActivity(i)
                    },
                    modifier = Modifier
                        .width(170.dp)
                        .height(60.dp)
                        .background(Color.Transparent),
                    colors = ButtonDefaults.buttonColors(
                        containerColor = colorResource(id = R.color.green),
                        contentColor = Color.White
                    ),
                    shape = RoundedCornerShape(12.dp)
                )
                {
                    Image(
                        painter = painterResource(R.drawable.ic_gam_logo),
                        contentDescription = "GAM",
                        modifier = Modifier
                            .padding(end = 5.dp)
                            .size(30.dp)
                    )
                    Text(
                        text = stringResource(id = R.string.gam_name),
                        style = TextStyle(fontSize = 12.sp)
                    )
                }
            }
        }
    }

}