package com.taiwanmobile.pt.guide.admob

import android.graphics.Color
import android.graphics.drawable.ColorDrawable
import android.os.Bundle
import android.text.SpannableString
import android.text.style.ForegroundColorSpan
import android.util.Log
import android.widget.Toast
import androidx.appcompat.app.AppCompatActivity
import androidx.core.content.ContextCompat
import com.google.android.gms.ads.*
import com.taiwanmobile.pt.guide.R
import com.taiwanmobile.pt.guide.databinding.ActivityBannerBinding

class BannerActivity : AppCompatActivity() {

    private var adView: AdView? = null
    private lateinit var binding: ActivityBannerBinding

    override fun onCreate(savedInstanceState: Bundle?) {
        super.onCreate(savedInstanceState)
        binding = ActivityBannerBinding.inflate(layoutInflater)
        val view = binding.root
        setContentView(view)
        val title = getString(R.string.banner_title)
        val spannableString = SpannableString(title)
        val titleColor = ContextCompat.getColor(this, R.color.white)
        val titleForegroundColorSpan = ForegroundColorSpan(titleColor)
        spannableString.setSpan(titleForegroundColorSpan, 0, title.length, 0)
        supportActionBar?.title = spannableString
        supportActionBar?.setBackgroundDrawable(ColorDrawable(Color.BLACK))

        val args = intent.extras
        if (args != null) {
            val adUnitId = args.getString(MainActivity.KEY_ADUNITID)
            val adSize: AdSize = when (args.getString(MainActivity.KEY_ADSIZE)) {
                BANNER_320x50 -> {
                    AdSize.BANNER
                }
                BANNER_300x250 -> {
                    AdSize.MEDIUM_RECTANGLE
                }
                else -> {
                    val displayMetrics = resources.displayMetrics
                    val dpWidth = (displayMetrics.widthPixels / displayMetrics.density).toInt()
                    AdSize.getCurrentOrientationAnchoredAdaptiveBannerAdSize(
                        this,
                        dpWidth
                    )
                }
            }

            // Banner initial
            adUnitId?.let {
                val request = AdRequest.Builder().build()
                adView = AdView(this@BannerActivity)
                adView?.adUnitId = it
                adView?.setAdSize(adSize)
                adView?.adListener = AdListenerImpl()
                adView?.loadAd(request)
                // add view into layout
                binding.adContainer.addView(adView)
            }
        }
    }

    private inner class AdListenerImpl : AdListener() {

        override fun onAdClosed() {}

        override fun onAdLoaded() {
        }

        override fun onAdFailedToLoad(adError : LoadAdError) {
            // Code to be executed when an ad request fails.
            Log.d("BannerActivity", "onAdFailedToLoad$adError")
            Toast.makeText(
                baseContext, "${adError.message}",
                Toast.LENGTH_SHORT
            ).show()
        }

        override fun onAdOpened() {
        }

        override fun onAdClicked() {
            Toast.makeText(
                baseContext, "onAdClicked invoked!!",
                Toast.LENGTH_SHORT
            ).show()
        }

        override fun onAdImpression() {
        }
    }

    override fun onDestroy() {
        super.onDestroy()
        adView?.destroy()
    }

    companion object {
        const val BANNER_320x50 = "320x50"
        const val BANNER_300x250 = "300x250"
    }
}