package com.taiwanmobile.pt.guide.admob

import android.graphics.Color
import android.graphics.drawable.ColorDrawable
import android.os.Bundle
import android.text.SpannableString
import android.text.style.ForegroundColorSpan
import android.widget.Toast
import androidx.appcompat.app.AppCompatActivity
import androidx.core.content.ContextCompat
import com.google.android.gms.ads.AdRequest
import com.google.android.gms.ads.LoadAdError
import com.google.android.gms.ads.interstitial.InterstitialAd
import com.google.android.gms.ads.interstitial.InterstitialAdLoadCallback
import com.taiwanmobile.pt.guide.R
import com.taiwanmobile.pt.guide.databinding.ActivityInterstitialBinding

class InterstitialActivity : AppCompatActivity() {

    private var interstitialAd: InterstitialAd? = null
    private var adUnitId: String? = null
    private lateinit var binding: ActivityInterstitialBinding

    override fun onCreate(savedInstanceState: Bundle?) {
        super.onCreate(savedInstanceState)
        binding = ActivityInterstitialBinding.inflate(layoutInflater)
        val view = binding.root
        setContentView(view)
        val title = getString(R.string.interstitial_title)
        val spannableString = SpannableString(title)
        val titleColor = ContextCompat.getColor(this, R.color.white)
        val titleForegroundColorSpan = ForegroundColorSpan(titleColor)
        spannableString.setSpan(titleForegroundColorSpan, 0, title.length, 0)
        supportActionBar?.title = spannableString
        supportActionBar?.setBackgroundDrawable(ColorDrawable(Color.BLACK))

        val args = intent.extras
        if (args != null) {
            adUnitId = args.getString(MainActivity.KEY_ADUNITID)
            adUnitId?.let {
                val adRequest = AdRequest.Builder().build()
                InterstitialAd.load(this, it, adRequest, object : InterstitialAdLoadCallback() {
                    override fun onAdLoaded(interstitialAd: InterstitialAd) {
                        // The mInterstitialAd reference will be null until
                        // an ad is loaded.
                        this@InterstitialActivity.interstitialAd = interstitialAd
                        Toast.makeText(
                            baseContext,
                            "onAdLoaded(interstitial) invoked!!",
                            Toast.LENGTH_SHORT
                        ).show()
                        interstitialAd.show(this@InterstitialActivity)
                    }

                    override fun onAdFailedToLoad(loadAdError: LoadAdError) {
                        Toast.makeText(
                            baseContext,
                            loadAdError.message,
                            Toast.LENGTH_SHORT
                        ).show()
                        interstitialAd = null
                    }
                })
            }
        }
    }
}