package com.taiwanmobile.pt.guide.admob

import android.content.Intent
import android.graphics.Color
import android.graphics.drawable.ColorDrawable
import android.os.Bundle
import android.text.SpannableString
import android.text.style.ForegroundColorSpan
import android.view.View
import androidx.appcompat.app.AppCompatActivity
import androidx.core.content.ContextCompat
import com.google.android.gms.ads.MobileAds
import com.taiwanmobile.pt.guide.BuildConfig.VERSION_CODE
import com.taiwanmobile.pt.guide.BuildConfig.VERSION_NAME
import com.taiwanmobile.pt.guide.R
import com.taiwanmobile.pt.guide.databinding.ActivityMainBinding


class MainActivity : AppCompatActivity() {

    private lateinit var binding: ActivityMainBinding

    override fun onCreate(savedInstanceState: Bundle?) {
        super.onCreate(savedInstanceState)
        binding = ActivityMainBinding.inflate(layoutInflater)
        val view = binding.root
        setContentView(view)
        binding.tvVersion.text = VERSION_NAME + "(${VERSION_CODE})"
        val title = getString(R.string.admob_name)
        val spannableString = SpannableString(title)
        val titleColor = ContextCompat.getColor(this, R.color.white)
        val titleForegroundColorSpan = ForegroundColorSpan(titleColor)
        spannableString.setSpan(titleForegroundColorSpan, 0, title.length, 0)
        supportActionBar?.title = spannableString
        supportActionBar?.setBackgroundDrawable(ColorDrawable(Color.BLACK))

        // Initialize Mobile Ads SDK
        MobileAds.initialize(this)
    }

    fun launchActivity(v: View) {
        val i = Intent()
        when (v.id) {
            R.id.btn_320x50 -> {
                i.putExtra(KEY_ADUNITID, ADUNIT_ID_BANNER_320x50)
                i.putExtra(KEY_ADSIZE, BannerActivity.BANNER_320x50)
                i.setClass(this@MainActivity, BannerActivity::class.java)
                startActivity(i)
            }
            R.id.btn_300x250 -> {
                i.putExtra(KEY_ADUNITID, ADUNIT_ID_BANNER_300x250)
                i.putExtra(KEY_ADSIZE, BannerActivity.BANNER_300x250)
                i.setClass(this@MainActivity, BannerActivity::class.java)
                startActivity(i)
            }
            R.id.btn_interstitial -> {
                i.putExtra(KEY_ADUNITID, ADUNIT_ID_INTERSTITIAL)
                i.setClass(this@MainActivity, InterstitialActivity::class.java)
                startActivity(i)
            }
            R.id.btn_native -> {
                i.putExtra(KEY_ADUNITID, ADUNIT_ID_NATIVE)
                i.setClass(this@MainActivity, NativeActivity::class.java)
                startActivity(i)
            }
            else -> {
            }
        }
    }

    companion object {
        private const val ADUNIT_ID_BANNER_320x50 = "ca-app-pub-3940256099942544/6300978111"
        private const val ADUNIT_ID_BANNER_300x250 = "ca-app-pub-3940256099942544/6300978111"
        private const val ADUNIT_ID_INTERSTITIAL = "ca-app-pub-3940256099942544/1033173712"
        private const val ADUNIT_ID_NATIVE = "ca-app-pub-3940256099942544/2247696110"
        const val KEY_ADUNITID = "adUnitId"
        const val KEY_ADSIZE = "adSize"
    }
}