package com.taiwanmobile.pt.guide.gam

import android.graphics.Color
import android.graphics.drawable.ColorDrawable
import android.os.Bundle
import android.text.SpannableString
import android.text.style.ForegroundColorSpan
import android.util.Log
import android.widget.Toast
import androidx.appcompat.app.AppCompatActivity
import androidx.core.content.ContextCompat
import com.google.android.gms.ads.AdListener
import com.google.android.gms.ads.AdSize
import com.google.android.gms.ads.LoadAdError
import com.google.android.gms.ads.admanager.AdManagerAdRequest
import com.google.android.gms.ads.admanager.AdManagerAdView
import com.taiwanmobile.pt.guide.R
import com.taiwanmobile.pt.guide.databinding.ActivityGamBannerBinding

class GAMBannerActivity : AppCompatActivity() {

    private var adManagerAdView: AdManagerAdView? = null
    private lateinit var binding: ActivityGamBannerBinding

    override fun onCreate(savedInstanceState: Bundle?) {
        super.onCreate(savedInstanceState)
        binding = ActivityGamBannerBinding.inflate(layoutInflater)
        val view = binding.root
        setContentView(view)
        val title = getString(R.string.banner_title)
        val spannableString = SpannableString(title)
        val titleColor = ContextCompat.getColor(this, R.color.white)
        val titleForegroundColorSpan = ForegroundColorSpan(titleColor)
        spannableString.setSpan(titleForegroundColorSpan, 0, title.length, 0)
        supportActionBar?.title = spannableString
        supportActionBar?.setBackgroundDrawable(ColorDrawable(Color.BLACK))

        val args = intent.extras
        if (args != null) {
            val adUnitId = args.getString(GAMMainActivity.KEY_ADUNITID)
            val adSize: AdSize = when (args.getString(GAMMainActivity.KEY_ADSIZE)) {
                BANNER_320x50 -> {
                    AdSize.BANNER
                }
                BANNER_300x250 -> {
                    AdSize.MEDIUM_RECTANGLE
                }
                else -> {
                    val displayMetrics = resources.displayMetrics
                    val dpWidth = (displayMetrics.widthPixels / displayMetrics.density).toInt()
                    AdSize.getCurrentOrientationAnchoredAdaptiveBannerAdSize(this, dpWidth)
                }
            }

            // Banner initial
            adUnitId?.let {
                val request = AdManagerAdRequest.Builder().build()
                adManagerAdView = AdManagerAdView(this@GAMBannerActivity)
                adManagerAdView?.adUnitId = it
                adManagerAdView?.setAdSizes(adSize)
                adManagerAdView?.adListener = object: AdListener() {
                    override fun onAdLoaded() {
                        Log.d("tag", "onAdImpression")
                    }

                    override fun onAdFailedToLoad(adError : LoadAdError) {
                        // Code to be executed when an ad request fails.
                        Log.d("tag", "onAdFailedToLoad$adError")
                        Toast.makeText(this@GAMBannerActivity, adError.message, Toast.LENGTH_SHORT).show()
                    }

                    override fun onAdClicked() {
                        Log.d("tag", "onAdImpression")
                    }

                    override fun onAdImpression() {
                        Log.d("tag", "onAdImpression")
                    }
                }
                adManagerAdView?.loadAd(request)
                // add view into layout
                binding.adContainer.addView(adManagerAdView)
            }
        }
    }

    override fun onDestroy() {
        super.onDestroy()
        adManagerAdView?.destroy()
    }

    companion object {
        const val BANNER_320x50 = "320x50"
        const val BANNER_300x250 = "300x250"
    }
}