package com.taiwanmobile.pt.guide.gam

import android.graphics.Color
import android.graphics.drawable.ColorDrawable
import android.os.Bundle
import android.text.SpannableString
import android.text.style.ForegroundColorSpan
import android.util.Log
import android.widget.Toast
import androidx.appcompat.app.AppCompatActivity
import androidx.core.content.ContextCompat
import com.google.android.gms.ads.LoadAdError
import com.google.android.gms.ads.admanager.AdManagerAdRequest
import com.google.android.gms.ads.admanager.AdManagerInterstitialAd
import com.google.android.gms.ads.admanager.AdManagerInterstitialAdLoadCallback
import com.taiwanmobile.pt.guide.R
import com.taiwanmobile.pt.guide.databinding.ActivityGamInterstitialBinding

class GAMInterstitialActivity : AppCompatActivity() {

    private var interstitialAd: AdManagerInterstitialAd? = null
    private var adUnitId: String? = null
    private lateinit var binding: ActivityGamInterstitialBinding

    override fun onCreate(savedInstanceState: Bundle?) {
        super.onCreate(savedInstanceState)
        binding = ActivityGamInterstitialBinding.inflate(layoutInflater)
        val view = binding.root
        setContentView(view)
        val title = getString(R.string.interstitial_title)
        val spannableString = SpannableString(title)
        val titleColor = ContextCompat.getColor(this, R.color.white)
        val titleForegroundColorSpan = ForegroundColorSpan(titleColor)
        spannableString.setSpan(titleForegroundColorSpan, 0, title.length, 0)
        supportActionBar?.title = spannableString
        supportActionBar?.setBackgroundDrawable(ColorDrawable(Color.BLACK))

        val args = intent.extras
        if (args != null) {
            adUnitId = args.getString(GAMMainActivity.KEY_ADUNITID)
            adUnitId?.let {
                val adRequest = AdManagerAdRequest.Builder().build()
                AdManagerInterstitialAd.load(this, it, adRequest, object : AdManagerInterstitialAdLoadCallback() {
                    override fun onAdFailedToLoad(adError: LoadAdError) {
                        Toast.makeText(this@GAMInterstitialActivity, adError.message, Toast.LENGTH_SHORT).show()
                        Log.d("tag", adError.toString())
                        interstitialAd = null
                    }
                    override fun onAdLoaded(ad: AdManagerInterstitialAd) {
                        Log.d("tag", "Ad was loaded")
                        interstitialAd = ad
                        interstitialAd?.show(this@GAMInterstitialActivity)
                    }
                })
            }
        }
    }
}