package com.taiwanmobile.pt.guide.gam

import android.content.Intent
import android.graphics.Color
import android.graphics.drawable.ColorDrawable
import android.os.Bundle
import android.text.SpannableString
import android.text.style.ForegroundColorSpan
import android.view.View
import androidx.appcompat.app.AppCompatActivity
import androidx.core.content.ContextCompat
import com.google.android.gms.ads.MobileAds
import com.taiwanmobile.pt.guide.BuildConfig.VERSION_CODE
import com.taiwanmobile.pt.guide.BuildConfig.VERSION_NAME
import com.taiwanmobile.pt.guide.R
import com.taiwanmobile.pt.guide.databinding.ActivityGamMainBinding


class GAMMainActivity : AppCompatActivity() {

    private lateinit var binding: ActivityGamMainBinding

    override fun onCreate(savedInstanceState: Bundle?) {
        super.onCreate(savedInstanceState)
        binding = ActivityGamMainBinding.inflate(layoutInflater)
        val view = binding.root
        setContentView(view)
        binding.tvVersion.text = VERSION_NAME + "(${VERSION_CODE})"
        val title = getString(R.string.gam_name)
        val spannableString = SpannableString(title)
        val titleColor = ContextCompat.getColor(this, R.color.white)
        val titleForegroundColorSpan = ForegroundColorSpan(titleColor)
        spannableString.setSpan(titleForegroundColorSpan, 0, title.length, 0)
        supportActionBar?.title = spannableString
        supportActionBar?.setBackgroundDrawable(ColorDrawable(Color.BLACK))

        // Initialize Mobile Ads SDK
        MobileAds.initialize(this)
    }

    fun launchActivity(v: View) {
        val i = Intent()
        when (v.id) {
            R.id.btn_320x50 -> {
                i.putExtra(KEY_ADUNITID, ADUNIT_ID_BANNER_320x50)
                i.putExtra(KEY_ADSIZE, GAMBannerActivity.BANNER_320x50)
                i.setClass(this@GAMMainActivity, GAMBannerActivity::class.java)
                startActivity(i)
            }
            R.id.btn_300x250 -> {
                i.putExtra(KEY_ADUNITID, ADUNIT_ID_BANNER_300x250)
                i.putExtra(KEY_ADSIZE, GAMBannerActivity.BANNER_300x250)
                i.setClass(this@GAMMainActivity, GAMBannerActivity::class.java)
                startActivity(i)
            }
            R.id.btn_interstitial -> {
                i.putExtra(KEY_ADUNITID, ADUNIT_ID_INTERSTITIAL)
                i.setClass(this@GAMMainActivity, GAMInterstitialActivity::class.java)
                startActivity(i)
            }
            R.id.btn_native -> {
                i.putExtra(KEY_ADUNITID, ADUNIT_ID_NATIVE)
                i.setClass(this@GAMMainActivity, GAMNativeActivity::class.java)
                startActivity(i)
            }
            R.id.btn_native_image -> {
                i.putExtra(KEY_ADUNITID, ADUNIT_ID_NATIVE_IMAGE)
                i.setClass(this@GAMMainActivity, GAMNativeActivity::class.java)
                startActivity(i)
            }
            else -> {
            }
        }
    }

    companion object {
        // Developer. 請改為Google Ad Manager廣告單元內容
        private const val ADUNIT_ID_BANNER_320x50 = "/6499/example/banner"
        private const val ADUNIT_ID_BANNER_300x250 = "/6499/example/banner"
        private const val ADUNIT_ID_INTERSTITIAL = "/6499/example/interstitial"
        private const val ADUNIT_ID_NATIVE = "/6499/example/native-video"
        private const val ADUNIT_ID_NATIVE_IMAGE = "/6499/example/native"
        const val KEY_ADUNITID = "adUnitId"
        const val KEY_ADSIZE = "adSize"
    }
}