package com.taiwanmobile.pt.guide.gam

import android.annotation.SuppressLint
import android.graphics.Color
import android.graphics.drawable.ColorDrawable
import android.os.Bundle
import android.text.SpannableString
import android.text.style.ForegroundColorSpan
import android.view.View
import android.widget.Toast
import androidx.appcompat.app.AppCompatActivity
import androidx.core.content.ContextCompat
import com.google.android.gms.ads.*
import com.google.android.gms.ads.admanager.AdManagerAdRequest
import com.google.android.gms.ads.nativead.NativeAd
import com.google.android.gms.ads.nativead.NativeAdOptions
import com.google.android.gms.ads.nativead.NativeAdView
import com.taiwanmobile.pt.guide.R
import com.taiwanmobile.pt.guide.databinding.ActivityNativeBinding
import com.taiwanmobile.pt.guide.databinding.NativeAdBinding


class GAMNativeActivity : AppCompatActivity() {

    private lateinit var binding: ActivityNativeBinding
    private var nativeAd: NativeAd? = null

    @SuppressLint("InflateParams")
    override fun onCreate(savedInstanceState: Bundle?) {
        super.onCreate(savedInstanceState)
        binding = ActivityNativeBinding.inflate(layoutInflater)
        val view = binding.root
        setContentView(view)
        val title = getString(R.string.native_title)
        val spannableString = SpannableString(title)
        val titleColor = ContextCompat.getColor(this, R.color.white)
        val titleForegroundColorSpan = ForegroundColorSpan(titleColor)
        spannableString.setSpan(titleForegroundColorSpan, 0, title.length, 0)
        supportActionBar?.title = spannableString
        supportActionBar?.setBackgroundDrawable(ColorDrawable(Color.BLACK))

        val args = intent.extras
        args?.let {
            val adUnitId = args.getString(GAMMainActivity.KEY_ADUNITID) ?: ""
            val adLoader = AdLoader.Builder(this, adUnitId)
                .forNativeAd { ad: NativeAd ->
                    // If this callback occurs after the activity is destroyed, you
                    // must call destroy and return or you may get a memory leak.
                    // Note `isDestroyed` is a method on Activity.
                    if (isDestroyed) {
                        ad.destroy()
                        return@forNativeAd
                    }
                    nativeAd = ad
                    val vb = NativeAdBinding.inflate(layoutInflater)
                    populateNativeAdView(ad, vb)
                    binding.nativeContainer.removeAllViews()
                    binding.nativeContainer.addView(vb.root)
                }
                .withAdListener(object : AdListener() {
                    override fun onAdFailedToLoad(adError: LoadAdError) {
                        Toast.makeText(this@GAMNativeActivity, "onAdFailedToLoad", Toast.LENGTH_SHORT)
                            .show()
                    }

                    override fun onAdClicked() {
                        super.onAdClicked()
                        Toast.makeText(this@GAMNativeActivity, "onAdClicked", Toast.LENGTH_SHORT)
                            .show()
                    }

                    override fun onAdImpression() {
                        super.onAdImpression()
                        Toast.makeText(this@GAMNativeActivity, "onAdImpression", Toast.LENGTH_SHORT)
                            .show()
                    }
                })
                .withNativeAdOptions(
                    NativeAdOptions.Builder()
                        // Methods in the NativeAdOptions.Builder class can be
                        // used here to specify individual options settings.
                        .build()
                )
                .build()
            adLoader.loadAd(AdManagerAdRequest.Builder().build())
        }
    }

    override fun onDestroy() {
        super.onDestroy()
        nativeAd?.destroy()
    }

    /**
     * Populates a [NativeAdView] object with data from a given [NativeAd].
     *
     * @param nativeAd the object containing the ad's assets
     * @param viewBinding the view binding object [NativeAdBinding] contains the [NativeAdView]
     */
    private fun populateNativeAdView(nativeAd: NativeAd, viewBinding: NativeAdBinding) {

        // fetch NativeAdView from NativeAdBinding
        val nativeAdView: NativeAdView = viewBinding.root

        // headline
        if (nativeAd.headline == null) {
            viewBinding.adHeadline.visibility = View.INVISIBLE
        } else {
            viewBinding.adHeadline.visibility = View.VISIBLE
            viewBinding.adHeadline.text = nativeAd.headline
            nativeAdView.headlineView = viewBinding.adHeadline
        }
        // body
        if (nativeAd.body == null) {
            viewBinding.adBody.visibility = View.INVISIBLE
        } else {
            viewBinding.adBody.visibility = View.VISIBLE
            viewBinding.adBody.text = nativeAd.body
            nativeAdView.bodyView = viewBinding.adBody
        }
        // call to action
        if (nativeAd.callToAction == null) {
            viewBinding.adCallToAction.visibility = View.INVISIBLE
        } else {
            viewBinding.adCallToAction.visibility = View.VISIBLE
            viewBinding.adCallToAction.text = nativeAd.callToAction
            nativeAdView.callToActionView = viewBinding.adCallToAction
        }
        // icon
        if (nativeAd.icon == null) {
            viewBinding.adAppIcon.visibility = View.GONE
        } else {
            nativeAd.icon?.drawable?.let {
                viewBinding.adAppIcon.setImageDrawable(it)
                viewBinding.adAppIcon.visibility = View.VISIBLE
                nativeAdView.iconView = viewBinding.adAppIcon
            }
        }
        // mediaView
        nativeAdView.mediaView = viewBinding.adMedia
        nativeAdView.mediaView?.mediaContent = nativeAd.mediaContent
        nativeAdView.setNativeAd(nativeAd)
    }

}